@@ -74,7 +74,7 @@ def GetValueInString(Value, str):
     else: 
        return    'FAIL'
        
-def FormatValidator(field_format, field_value): 
+def StringFormatValidator(field_format, field_value): 
     """
      Returns PASS if the field_value matches a specified field format (field_format)
      Returns FAIL if the field_value does not match a specified field format (field_format).
@@ -202,7 +202,7 @@ def GetDataRowCount(filename, sheetname) :
     """
     Returns the number rows in a particular sheetname of an excel file
     """
-    workbook = xlrd.open_workbook(fileName)
+    workbook = xlrd.open_workbook(filename)
     worksheet = workbook.sheet_by_name(sheetname)
     rowEndIndex = worksheet.nrows - 1   
     return rowEndIndex
@@ -244,7 +244,7 @@ def GetNextAvailableDataRow(filename, sheetname, used_col_letter):
      wb.save(filename) # Save the workbook                                                	     
      return data_row  # return the row of test data
 
-def GetAllDataFromExcelFile(fileName, sheetname) :
+def GetAllDataFromExcelSheet(fileName, sheetname) :
     """
     Returns all of the rows of data from a particular sheetname of an excel file
     """
@@ -255,7 +255,7 @@ def GetAllDataFromExcelFile(fileName, sheetname) :
     rowStartIndex = 1
     colStartIndex = 0
     testData = []
-    dataRow = []
+    dataRows = []
     curr_row = rowStartIndex
     while curr_row <= rowEndIndex:
          cur_col = colStartIndex
@@ -263,7 +263,8 @@ def GetAllDataFromExcelFile(fileName, sheetname) :
              cell_type = worksheet.cell_type(curr_row, cur_col)
 
              value = worksheet.cell_value(curr_row, cur_col)
-             dataRow.append(value)
+             dataRows.append(value)
              cur_col+=1
          curr_row += 1
-         testData.append(dataRow)
+         testData.append(dataRows)
+    return dataRows
